@@ -1,8 +1,10 @@
+//go:build !tinygo
+// +build !tinygo
+
 package middleware
 
 import (
 	"expvar"
-	"fmt"
 	"net/http"
 	"net/http/pprof"
 
@@ -11,13 +13,13 @@ import (
 
 // Profiler is a convenient subrouter used for mounting net/http/pprof. ie.
 //
-//  func MyService() http.Handler {
-//    r := chi.NewRouter()
-//    // ..middlewares
-//    r.Mount("/debug", middleware.Profiler())
-//    // ..routes
-//    return r
-//  }
+//	func MyService() http.Handler {
+//		r := chi.NewRouter()
+//		// ..middlewares
+//		r.Mount("/debug", middleware.Profiler())
+//		// ..routes
+//		return r
+//	}
 func Profiler() http.Handler {
 	r := chi.NewRouter()
 	r.Use(NoCache)
@@ -34,7 +36,7 @@ func Profiler() http.Handler {
 	r.HandleFunc("/pprof/profile", pprof.Profile)
 	r.HandleFunc("/pprof/symbol", pprof.Symbol)
 	r.HandleFunc("/pprof/trace", pprof.Trace)
-	r.HandleFunc("/vars", expVars)
+	r.Handle("/vars", expvar.Handler())
 
 	r.Handle("/pprof/goroutine", pprof.Handler("goroutine"))
 	r.Handle("/pprof/threadcreate", pprof.Handler("threadcreate"))
@@ -45,18 +47,3 @@ func Profiler() http.Handler {
 
 	return r
 }
-
-// Replicated from expvar.go as not public.
-func expVars(w http.ResponseWriter, r *http.Request) {
-	first := true
-	w.Header().Set("Content-Type", "application/json")
-	fmt.Fprintf(w, "{\n")
-	expvar.Do(func(kv expvar.KeyValue) {
-		if !first {
-			fmt.Fprintf(w, ",\n")
-		}
-		first = false
-		fmt.Fprintf(w, "%q: %s", kv.Key, kv.Value)
-	})
-	fmt.Fprintf(w, "\n}\n")
-}
